summaryrefslogtreecommitdiff
path: root/sql/item_func.cc
diff options
context:
space:
mode:
authorSergei Golubchik <serg@mariadb.org>2016-03-21 13:02:53 +0100
committerSergei Golubchik <serg@mariadb.org>2016-03-21 13:02:53 +0100
commit3b0c7ac1f9d64afc933ce0354037c709366b7dff (patch)
tree39cefed54f79f93f82e9c33a4e094270103bf137 /sql/item_func.cc
parente7cf898d6dc3dcac41f58db4761df3a6d1dffc03 (diff)
parent22ebf3cb456e0d8db295e7cc93f08e3d3ecfea47 (diff)
downloadmariadb-git-3b0c7ac1f9d64afc933ce0354037c709366b7dff.tar.gz
Merge branch '10.0' into 10.1
Diffstat (limited to 'sql/item_func.cc')
-rw-r--r--sql/item_func.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/sql/item_func.cc b/sql/item_func.cc
index f61270ee208..e5c1f4c75f6 100644
--- a/sql/item_func.cc
+++ b/sql/item_func.cc
@@ -232,7 +232,7 @@ Item_func::fix_fields(THD *thd, Item **ref)
}
}
fix_length_and_dec();
- if (thd->is_error()) // An error inside fix_length_and_dec occured
+ if (thd->is_error()) // An error inside fix_length_and_dec occurred
return TRUE;
fixed= 1;
return FALSE;
@@ -5652,7 +5652,7 @@ void Item_func_get_user_var::fix_length_and_dec()
/*
If the variable didn't exist it has been created as a STRING-type.
- 'm_var_entry' is NULL only if there occured an error during the call to
+ 'm_var_entry' is NULL only if there occurred an error during the call to
get_var_with_binlog.
*/
if (!error && m_var_entry)